@@ -18,6 +18,8 @@
 #include "grammar.h"
 #include "task.h"
 #include "eparam.h"
+#include "proto.h"
+
 
 /*
  * EPARAM -- Screen editor for parameter files.
@@ -64,7 +66,7 @@ static	int cmdline;			/* last line on screen		      */
 static	int maxcol;			/* last column on screen	      */
 static	int line, topline, botline;	/* current, top, bottom lines	      */
 static	int col, startcol, nextcol;	/* current, first, last columns	      */
-static	int tty_fd, tty;		/* define the terminal globally       */
+static	XINT tty_fd, tty;		/* define the terminal globally       */
 static	int botkeyline, nextline,	/* various global variables for       */
 	    keyid, numkeys, topkey,	/*   keeping track of lines and keys  */
 	    botkey, nextkey;
@@ -96,8 +98,10 @@ char	*e_tonextword(), *e_toprevword(), *index();
  * in pfiles, load psets from pfiles, and so on.  ERR is returned if the user
  * wants to quit altogether, e.g., when epset is called in a loop.
  */
-epset (pset)
-char	*pset;			/* ltaskname or pfilename */
+int
+epset (
+  char	*pset			/* ltaskname or pfilename */
+)
 {
 	struct  ep_context context[20], *cx;
 	char    newpset[SZ_FNAME+1];
@@ -182,11 +186,13 @@ char	*pset;			/* ltaskname or pfilename */
  * structure, allowing the editor to be reentered at the same point
  * on the old pset.
  */
-eparam (cx, update, nextcmd, nextpset)
-struct	ep_context *cx;		/* eparam editor context	*/
-int	*update;		/* update pset upon exit	*/
-int	*nextcmd;		/* receives next command	*/
-char	*nextpset;		/* receives next pset name	*/
+int
+eparam (
+  struct ep_context *cx,		/* eparam editor context	*/
+  int	*update,			/* update pset upon exit	*/
+  int	*nextcmd,			/* receives next command	*/
+  char	*nextpset 			/* receives next pset name	*/
+)
 {
 	char	string[G_MAXSTRING];
 
@@ -199,7 +205,7 @@ char	*nextpset;		/* receives next pset name	*/
 
 	/* When we are called to edit a file, the ltask ptr is NULL.
 	 */
-	if (ep_filemode = (pfilep->pf_ltp == NULL))
+	if ((ep_filemode = (pfilep->pf_ltp == NULL)))
 	    topline--;			/* room for one more param line */
 
 	numkeys = e_makelist (pfilep);	/* initialize parameter list	*/
@@ -279,8 +285,10 @@ exit:
  * multiline prompt environment, we need a table of pointers to the firstline
  * of each keyword.
  */
-e_makelist (pfileptr)
-struct	pfile  *pfileptr;
+int
+e_makelist (
+  struct pfile  *pfileptr
+)
 {
 	register struct param *pp;
 	register char c, *p;
@@ -380,9 +388,11 @@ struct	pfile  *pfileptr;
 /* E_TESTTOP -- Check to see if we have filled up a screen and if so,
  * start a new page.
  */
-e_testtop (cur, new)
-int	cur;			/* current line count on screen */
-int	new;			/* new count, returned if new page */
+int
+e_testtop (
+  int	cur,			/* current line count on screen */
+  int	new 			/* new count, returned if new page */
+)
 {
 	if (cur > (botline - topline + 1)) {
 	    topkeys[++maxpage] = numkeys;
@@ -394,10 +404,10 @@ int	new;			/* new count, returned if new page */
 
 /* E_REPAINT -- Repaint the current screen.
  */
-e_repaint()
+void
+e_repaint (void)
 {
 	static	char *static_prompt = "--------- parameter array ---------";
-	char	promptbuf[MAXPROMPT];
 	char	outbuf[MAXPROMPT];
 	int	i, keylin, ll, cc;
 	char	*p;
@@ -468,10 +478,12 @@ e_repaint()
 
 /* E_PHEADER -- Print the EPARAM form header.
  */
-e_pheader (pfp, cmdline, maxcol)
-struct	pfile *pfp;		/* pfile pointer		*/
-int	cmdline;		/* terminal command line number	*/
-int	maxcol;			/* max cols on a line		*/
+void
+e_pheader (
+  struct pfile *pfp,		/* pfile pointer		*/
+  int	cmdline,		/* terminal command line number	*/
+  int	maxcol 			/* max cols on a line		*/
+)
 {
 	static	char	*logo = "  I R A F  ";
 	static  char	*title= "Image Reduction and Analysis Facility";
@@ -535,12 +547,13 @@ int	maxcol;			/* max cols on a line		*/
  * For maximum drawing speed output is optimized using line clears and screen 
  * gotos rather than blanks to erase and position text.
  */
-e_drawkey()
+void
+e_drawkey (void)
 {
 	char	valuebuf[MAXPROMPT];
 	char	tempbuf[MAXPROMPT];
 	int	offset, nchars;
-	char	*p;
+
 
 	e_encode_vstring (parmlist[keyid], valuebuf);
 	e_goto (1, line);
@@ -615,9 +628,11 @@ int	indent;
  * get several of the values.  If it is an array, make sure the undefined values
  * get a '***', without calling spparval (which would bomb).
  */
-e_encode_vstring (pp, outbuf)
-struct	param *pp;
-char	*outbuf;
+void
+e_encode_vstring (
+  struct param *pp,
+  char	*outbuf
+)
 {
 	char valuebuf[G_MAXSTRING];
 	char colbuf[16];
@@ -682,8 +697,10 @@ char	*outbuf;
  * the array and check it.  Also check whether there are enough elements in the
  * array.  In any case, if gquery returns an error, report that to the user.
  */
-e_check_vals (string)
-char    *string;
+void
+e_check_vals (
+  char    *string
+)
 {
 	char *gquery();		/* declare gquery as returning a pointer  */
 	char *errstr;		/* pointer to the error string (or 0)     */
@@ -702,7 +719,7 @@ char    *string;
 
 	if (isarray) {
 	    char    outstring[G_MAXSTRING];
-	    char    *in, *out, *e_getfield();
+	    char    *in, *e_getfield();
 	    int	    first, nelem, flen;
 	    
 	    /* Get the length of the first dimension, and the starting point.
@@ -769,8 +786,10 @@ char    *string;
 
 /* E_UNDEF -- Recognize the undefined string of 3 asterisks.
  */
-e_undef (s)
-register char *s;
+int
+e_undef (
+  register char *s
+)
 {
 	register int	n = 0;
 
@@ -787,8 +806,10 @@ static	char	message[SZ_LINE];	/* used by e_rpterror and e_clrerror */
 
 /* E_RPTERROR -- Report the error for the eparam user.
  */
-e_rpterror (errstr)
-char	*errstr;
+void
+e_rpterror (
+  char	*errstr
+)
 {
 	char	*range;		/* pointer to the range error string	*/
 
@@ -821,7 +842,8 @@ char	*errstr;
 
 /* E_CLRERROR -- Clear the error line, i.e. the last error message.
  */
-e_clrerror ()
+void
+e_clrerror (void)
 {
 	register int	i, len;
 
@@ -848,10 +870,11 @@ e_clrerror ()
  * after the token.
  */
 char *
-e_getfield (ip, outstr, maxch)
-register char	*ip;		/* pointer into input string	*/
-char	*outstr;		/* receives token		*/
-int	maxch;			/* max chars out		*/
+e_getfield (
+  register char	*ip,		/* pointer into input string	*/
+  char	*outstr,		/* receives token		*/
+  int	maxch 			/* max chars out		*/
+)
 {
 	register char	*op, *otop;
 
@@ -872,11 +895,13 @@ int	maxch;			/* max chars out		*/
 /* E_MOREFLAG -- Signal that there are more parameters above or below the
  * window.
  */
-e_moreflag (topkey)
-register int topkey;
+int
+e_moreflag (
+  register int topkey
+)
 {
 	if ((numkeys == botkey) && (topkey == 1))
-	    return;
+	    return (OK);
 
 	if (botkey < numkeys) {
 	    e_ctrl ("so");
@@ -899,12 +924,15 @@ register int topkey;
 	e_ctrl ("se");
 	e_ctrl ("ue");
 	fflush (stdout);
+
+	return (OK);
 }
 
 
 /* E_SCROLLIT -- Scroll the window if possible.
  */
-e_scrollit()
+int
+e_scrollit (void)
 {
 	register int i;
 
@@ -936,6 +964,8 @@ e_scrollit()
 		}
 	    }
 	}
+
+	return (OK);
 }
 
 
@@ -955,9 +985,11 @@ e_scrollit()
  * A 'return' or EXIT_UPDATE will execute the edited command.
  * An EXIT_NOUPDATE will not execute the edited command.
  */
-edit_history_directive (args, new_cmd)
-char	*args;			/* ehistory argument list */
-char	*new_cmd;		/* the command to be executed after editing */
+int
+edit_history_directive (
+  char	*args,			/* ehistory argument list */
+  char	*new_cmd 		/* the command to be executed after editing */
+)
 {
 	static	char *firstchr[MAX_COMMANDS]; /*array of character pointers */
 	static	char string[G_MAXSTRING];
@@ -1100,9 +1132,11 @@ char	*new_cmd;		/* the command to be executed after editing */
 /* EDITSTRING -- A very limited string editor for interactive input.  The number
  * of characters in the edited string is returned as the function value.
  */
-editstring (string, eparam)
-char	*string;
-int	eparam;				/* flag to indicate eparam or ehis  */
+int
+editstring (
+  char	*string,
+  int	eparam 				/* flag to indicate eparam or ehis  */
+)
 {
 	char	oldchar;		/* save old character after delete  */
 	char    oldword[G_MAXSTRING];   /* save the deleted word            */
@@ -1512,7 +1546,8 @@ int	eparam;				/* flag to indicate eparam or ehis  */
 /* E_TTYINIT -- Initialize the terminal, i.e., set raw mode and standout mode
  * (if enabled).  Get dimensions of terminal screen.
  */
-e_ttyinit()
+void
+e_ttyinit (void)
 {
 	/* Open the tty (termcap) descriptor for the terminal.
 	 */
@@ -1529,8 +1564,8 @@ e_ttyinit()
 	 * interface case mapping is disabled.  Determine if ucasein and
 	 * ucaseout have been selected, e.g., with `stty ucasein ucaseout'.
 	 */
-	e_ucasein  = c_ttstati (STDIN,  TT_UCASEIN);
-	e_ucaseout = c_ttstati (STDOUT, TT_UCASEOUT);
+	e_ucasein  = c_ttstati ((XINT)STDIN,  TT_UCASEIN);
+	e_ucaseout = c_ttstati ((XINT)STDOUT, TT_UCASEOUT);
 
 	/* Get the dimensions of the terminal screen from the environment.
 	 * These need not agree with the physical screen dimensions given
@@ -1552,7 +1587,8 @@ e_ttyinit()
  * does not exit when an invalid colon escape is entered.  EP_EOF is returned
  * as the function value if eparam is to exit.
  */
-e_colon()
+int
+e_colon (void)
 {
 	register char	*ip, *op;
 	register int	ch;
@@ -1561,7 +1597,7 @@ e_colon()
 	int	ucasein_set;
 	int	force, n;
 
-	ucasein_set = c_ttstati (STDIN, TT_UCASEIN);
+	ucasein_set = c_ttstati ((XINT)STDIN, TT_UCASEIN);
 
 	/* Go to the command line, clear it and read the string value.
 	 * The read is performed in raw mode to avoid a line feed and scroll
@@ -1614,7 +1650,7 @@ again_:
 	ch = *ip++;
 	if (ch == 'g' && *ip == 'o')
 	    ip++;
-	if (force = (*ip == '!'))
+	if ((force = (*ip == '!')))
 	    ip++;
 	for (;  isspace (*ip);  ip++)
 	    ;
@@ -1673,6 +1709,13 @@ again_:
 	    } else {
 		if (e_psetok (pset)) {
 		    pfilemerge (e_cx->e_cpfp, pset);
+
+                    /* If we're forcing the new parameters, update
+                     * the pfile on disk so we can execute it immediately.
+                     */
+                    if (force) 
+                        n = pfilewrite (pfilep, pfilep->pf_pfilename);
+
 		    e_repaint();
 		    return (OK);
 		} else
@@ -1749,12 +1792,14 @@ again_:
 /* E_PSETOK -- Verify that the named pfile exists and can be read.  Report
  * any problems to the user.
  */
-e_psetok (pset)
-char	*pset;
+int
+e_psetok (
+  char	*pset
+)
 {
 	register struct pfile *pfp;
 	char	errmsg[SZ_LINE+1], *errfmt, *errarg;
-	int	save_topd;
+	XINT	save_topd;
 
 	save_topd = topd;
 	errarg = pset;
@@ -1785,7 +1830,7 @@ char	*pset;
 		errfmt = e_pcknonexist;
 		errarg = pk;
 		goto error_;
-	    } else if ((int)pkp == ERR) {
+	    } else if ((XINT)pkp == ERR) {
 		errfmt = e_pckambig;
 		errarg = pk;
 		goto error_;
@@ -1793,7 +1838,7 @@ char	*pset;
 		errfmt = e_tnonexist;
 		errarg = lt;
 		goto error_;
-	    } else if ((int)ltp == ERR) {
+	    } else if ((XINT)ltp == ERR) {
 		errfmt = e_tambig;
 		errarg = lt;
 		goto error_;
@@ -1825,8 +1870,10 @@ error_:
 
 /* E_PUTERR -- Put an error message on the command line.
  */
-e_puterr (errmsg)
-char	*errmsg;
+void
+e_puterr (
+  char	*errmsg
+)
 {
 	c_ttygoto (tty_fd, tty, 1, cmdline);
 	c_ttyclearln (tty_fd, tty);
@@ -1837,7 +1884,8 @@ char	*errmsg;
 /* E_TTYEXIT -- Turn off raw mode and standout mode and close the termcap
  * descriptor, leaving everything as we found it.
  */
-e_ttyexit()
+void
+e_ttyexit (void)
 {
 	c_fseti (fileno(stdin), F_RAW, NO);	/* unset raw mode */
 
@@ -1851,8 +1899,10 @@ e_ttyexit()
 
 /* E_MOVEUP -- Move the cursor up one line.
  */
-e_moveup (eparam)
-int	eparam;
+int
+e_moveup (
+  int	eparam
+)
 {
 	if (keyid != 1) {
 	    /* Can go up further.
@@ -1886,8 +1936,10 @@ int	eparam;
 
 /* E_MOVEDOWN -- Move the cursor down one line.
  */
-e_movedown (eparam)
-int	eparam;
+int
+e_movedown (
+  int	eparam
+)
 {
 	if (keyid != numkeys) { 
 	    /* get downnnnn!! 
@@ -1929,8 +1981,9 @@ int	eparam;
 /* E_TONEXTWORD -- Skip forward to the beginning of the next word.
  */
 char *
-e_tonextword (ip)
-register char	*ip;
+e_tonextword (
+  register char	*ip
+)
 {
 	ip++;
 
@@ -1949,9 +2002,10 @@ register char	*ip;
 /* E_TOPREVWORD -- Find the beginning of the previous word.
  */
 char *
-e_toprevword (ip, string)
-char	*ip;
-char	*string;
+e_toprevword (
+  char	*ip,
+  char	*string
+)
 {
 	--ip;
 
@@ -1974,8 +2028,10 @@ char	*string;
 
 /* E_CTRL -- Send a control sequence to the terminal.
  */
-e_ctrl (cap)
-char	*cap;
+void
+e_ctrl (
+  char	*cap
+)
 {
 	/* Check for start standout or start underline mode.
 	 */
@@ -1989,8 +2045,11 @@ char	*cap;
 
 /* E_GOTO -- High level edcap version of ttygoto (cursor addressing).
  */
-e_goto (col, line)
-int    col, line;
+void
+e_goto (
+  int    col, 
+  int    line
+)
 {
 	c_ttygoto (tty_fd, tty, col, line);
 }
@@ -1999,8 +2058,10 @@ int    col, line;
 /* E_PUTLINE -- Put a line of text to the terminal.  Do not map any embedded
  * control codes (bell will get lost).
  */
-e_putline (stwing)
-char      *stwing;
+void
+e_putline (
+  char      *stwing
+)
 {
 	register char	*ip, *op;
 	register int	ch, n;
@@ -2031,7 +2092,8 @@ char      *stwing;
 
 /* E_CLEAR -- Clear the screen (disables standout mode as a side effect).
  */
-e_clear()
+void
+e_clear (void)
 {
 	c_ttyctrl (tty_fd, tty, "se", 1);
 	c_ttyctrl (tty_fd, tty, "ue", 1);
@@ -2041,7 +2103,8 @@ e_clear()
 
 /* E_CLRLINE -- Clear the current line.
  */
-e_clrline()
+void
+e_clrline (void)
 {
 	c_ttyclearln (tty_fd, tty);
 }
@@ -2051,9 +2114,12 @@ e_clrline()
  * coordinates.  Each line is written starting at the same column on the
  * screen.
  */
-e_display (string, sline, scol)
-char	*string;		/* string to be printed		*/
-int	sline, scol;		/* starting line and column	*/
+void
+e_display (
+  char	*string,		/* string to be printed		*/
+  int	sline, 
+  int   scol 			/* starting line and column	*/
+)
 {
 	e_displayml (string, sline, scol, scol);
 }
@@ -2064,10 +2130,13 @@ int	sline, scol;		/* starting line and column	*/
  * line begins with \r (CR) it will be displayed starting at column 1, rather
  * than starting at column scol.
  */
-e_displayml (string, sline, scol, ccol)
-char	*string;		/* string to be printed			*/
-int	sline, scol;		/* starting line and column		*/
-int	ccol;			/* start col of continuation lines	*/
+void
+e_displayml (
+  char	*string,		/* string to be printed			*/
+  int	sline, 			/* starting line and column		*/
+  int   scol,
+  int	ccol 			/* start col of continuation lines	*/
+)
 {
 	register char	*ip, *op;
 	char	lbuf[512], *line;
