@@ -1,18 +1,21 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
 #include "bootlib.h"
 
 #define	SZ_CMD		2048
 
 /* OS_CMD -- Send a command to the host system.
  */
-os_cmd (cmd)
-char	*cmd;
+int
+os_cmd (char *cmd)
 {
 	PKCHAR	x_cmd[SZ_CMD+1];
 	PKCHAR	nullstr[1];
-	int	status;
+	XINT	status;
+	extern  int ZOSCMD();
+
 
 	strncpy ((char *)x_cmd, cmd, SZ_CMD);
 	nullstr[0] = 0;
