@@ -1,19 +1,25 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <fcntl.h>
 #include "bootlib.h"
 
+
 /* OS_CREATEFILE -- Open a new file for writing.  Create the file with the
  * given mode bits.
  */
-os_createfile (fname, mode, type)
-char	*fname;
-int	mode;
-int	type;
+int
+os_createfile (
+  char	*fname,
+  int	mode,
+  int	type
+)
 {
 	static	XINT xmode = NEW_FILE;
 	PKCHAR	*osfn = (PKCHAR *) vfn2osfn (fname, 1);
 	XINT	chan;
+	extern  int ZOPNTX();
+
 
 	if (bdebug)
 	    fprintf (stderr, "create %s file `%s' -> `%s'\n",
