@@ -3,12 +3,16 @@
 
 #include "bootlib.h"
 
+
 /* OS_DELETE -- Delete a file.
  */
-os_delete (fname)
-char	*fname;
+int
+os_delete (char *fname)
 {
-	int	status;
+	XINT	status;
+
+	extern  int ZFDELE();
+
 
 	ZFDELE ((PKCHAR *)vfn2osfn (fname, 0), &status);
 	return (status);
