@@ -3,7 +3,11 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <stdlib.h>
+#include <unistd.h>
 #include "xpp.h"
+#include "../../bootProto.h"
 
 #define	import_spp
 #include <iraf.h>
@@ -30,30 +34,6 @@
  * greater machine independence.
  */
 
-#define	F77			/* Fortran 77 target compiler?		*/
-
-#define	IRAFLIB		"iraf$lib/"
-#define	HOSTLIB		"host$hlib/"
-
-/* Size limiting definitions.
- */
-#define MAX_TASKS	100	/* max no. of tasks we can handle	*/
-#define SZ_OBUF		131072	/* buffers procedure body		*/
-#define SZ_DBUF		4096	/* for errchk, common, ect. decls	*/
-#define SZ_SBUF		8192	/* buffers text of strings		*/
-#define MAX_STRINGS	256	/* max strings in a procedure		*/
-#define MAX_INCLUDE	5	/* maximum nesting of includes		*/
-#define	MIN_REALPREC	7	/* used by HMS				*/
-#define	SZ_NUMBUF	32	/* for numeric constants		*/
-#define	SZ_STBUF	4096	/* text of defined strings		*/
-#define	MAX_DEFSTR	128	/* max defined strings			*/
-
-#define	RUNTASK		"sysruk.x"
-#define OCTAL		8
-#define DECIMAL		10
-#define HEX		16
-#define CHARCON		1
-#define SEXAG		2
 
 extern	char *vfn2osfn();
 
@@ -70,16 +50,19 @@ char	*esc_val = "\n\t\f\r\\\"\'";
 extern	char	yytext[];		/* LEX character buffer		*/
 extern	int	yyleng;			/* length of string in yytext	*/
 extern	FILE	*yyin, *yyout;		/* LEX input, output files	*/
+
 extern	char	yytchar, *yysptr, yysbuf[];
 extern	int	yylineno;
 
 #define U(x) x
-#define input() (((yytchar=yysptr>yysbuf?U(*--yysptr):getc(yyin))==10\
-?(yylineno++,yytchar):yytchar)==EOF?0:yytchar)
-#define unput(c) {yytchar= (c);if(yytchar=='\n')yylineno--;*yysptr++=yytchar;}
+
+extern int   yy_input(void);
+extern void  yy_unput(char ch);
+extern void  d_codegen (register FILE *fp);
+extern void  d_runtime (char *text);
 
 int	context = GLOBAL;		/* lexical context variable	*/
-extern	int foreigndefs;
+extern	int hbindefs, foreigndefs;
 char	*machdefs[] = { "mach.h", "config.h", "" };
 
 /* The task structure is used for TASK declarations.  Since this is a
@@ -116,7 +99,7 @@ char	sbuf[SZ_SBUF];			/* string buffer 		      */
 char	*sp = sbuf;			/* string buffer pointer	      */
 char	*op = obuf;			/* pointer in output buffer	      */
 char	*dp = dbuf;			/* pointer in decls buffer	      */
-int	nstrings;			/* number of strings so far	      */
+int	nstrings = 0;			/* number of strings so far	      */
 int	strloopdecl;			/* data dummy do index declared?      */
 
 int	ntasks = 0;			/* number of tasks in interpreter     */
@@ -128,13 +111,58 @@ int	errhand = NO;			/* set if proc employs error handler  */
 int	errchk = NO;			/* set if proc employs error checking */
 
 
+void  skipnl (void);
+void  setcontext (int new_context);
+void  pushcontext (int new_context);
+int   popcontext (void);
+void  hashtbl (void);
+int   findkw (void);
+void  mapident (void);
+void  str_enter (void);
+char *str_fetch (register char *strname);
+void  macro_redef (void);
+void  setline (void);
+void  output (char ch);
+
+void  do_type (int type);
+void  do_char (void);
+void  skip_helpblock (void);
+int   parse_task_statement (void);
+int   get_task (char *task_name, char *proc_name, int maxch);
+int   get_name (char *outstr, int maxch);
+int   nextch (void);
+void  put_dictionary (void);
+void  put_interpreter (void);
+void  outstr (char *string);
+void  begin_code (void);
+void  end_code (void);
+void  init_strings (void);
+void  write_string_data_statement (struct string *s);
+void  do_string (char delim, int strtype);
+void  do_hollerith (void);
+void  sbuf_check (void);
+
+char *str_uniqid (void);
+void  traverse (char delim);
+void  error (int errcode, char *errmsg);
+void  xpp_warn (char *warnmsg);
+long  accum (int base, char **strp);
+
+int   charcon (char *string);
+void  int_constant (char *string, int base);
+void  hms (char *number);
+
+
+
 /* SKIPNL -- Skip to newline, e.g., when a comment is encountered.
  */
-skipnl()
+void
+skipnl (void)
 {
-	while (input() != '\n')
+	int c;
+	while ((c=yy_input()) != '\n')
 	    ;
-	unput ('\n');
+	yy_unput ('\n');
 }
 
 
@@ -153,8 +181,8 @@ int	cntxsp = 0;		/* save stack pointer		*/
 
 /* SETCONTEXT -- Set the context.  Clears any saved context.
  */
-setcontext (new_context)
-int	new_context;
+void
+setcontext (int new_context)
 {
 	context = new_context;
 	cntxsp = 0;
@@ -163,8 +191,8 @@ int	new_context;
 
 /* PUSHCONTEXT -- Push a temporary context.
  */
-pushcontext (new_context)
-int	new_context;
+void
+pushcontext (int new_context)
 {
 	cntxstk[cntxsp++] = context;
 	context = new_context;
@@ -178,7 +206,8 @@ int	new_context;
  * (just finished compiling a procedure statement) then set the context to DECL
  * to indicate that we are entering the declarations section of a procedure.
  */
-popcontext()
+int
+popcontext (void)
 {
 	if (context & PROCSTMT) {
 	    context = DECL;
@@ -203,25 +232,25 @@ struct {
 				 * to get to next character class.
 				 */
 } kwtbl[] = {
-	"FALSE",	XTY_FALSE,	0,
-	"TRUE",		XTY_TRUE,	0,
-	"bool",		XTY_BOOL,	0,
-	"char",		XTY_CHAR,	1,
-	"complex",	XTY_COMPLEX,	0,
-	"double",	XTY_DOUBLE,	0,
-	"error",	XTY_ERROR,	1,
-	"extern",	XTY_EXTERN,	0,
-	"false",	XTY_FALSE,	0,
-	"iferr",	XTY_IFERR,	2,
-	"ifnoerr",	XTY_IFNOERR,	1,
-	"int",		XTY_INT,	0,
-	"long",		XTY_LONG,	0,
-	"pointer",	XTY_POINTER,	1,
-	"procedure",	XTY_PROC,	0,
-	"real",		XTY_REAL,	0,
-	"short",	XTY_SHORT,	0,
-	"true",		XTY_TRUE,	0,
-	};
+    { "FALSE",	    XTY_FALSE,	  0 },
+    { "TRUE",	    XTY_TRUE,	  0 },
+    { "bool",	    XTY_BOOL,	  0 },
+    { "char",	    XTY_CHAR,	  1 },
+    { "complex",    XTY_COMPLEX,  0 },
+    { "double",	    XTY_DOUBLE,	  0 },
+    { "error",	    XTY_ERROR,	  1 },
+    { "extern",	    XTY_EXTERN,	  0 },
+    { "false",	    XTY_FALSE,	  0 },
+    { "iferr",	    XTY_IFERR,	  2 },
+    { "ifnoerr",    XTY_IFNOERR,  1 },
+    { "int",	    XTY_INT,	  0 },
+    { "long",	    XTY_LONG,	  0 },
+    { "pointer",    XTY_POINTER,  1 },
+    { "procedure",  XTY_PROC,	  0 },
+    { "real",	    XTY_REAL,	  0 },
+    { "short",	    XTY_SHORT,	  0 },
+    { "true",	    XTY_TRUE,	  0 },
+};
 
 /* short kwindex[30];		simple alphabetic hash index		*/
 /* #define CINDEX(ch)		(isupper(ch)?ch-'A':ch-'a')		*/
@@ -236,11 +265,12 @@ short	kwindex[MAXCH];		/* simple alphabetic hash index		*/
  * sorted keyword table.  If there is no keyword name beginning with the index
  * character, the index entry is set to -1.
  */
-hashtbl()
+void
+hashtbl (void)
 {
 	int	i, j;
 
-	for (i=j=0;  i <= MAXCH;  i++) {
+	for (i=j=0;  i < MAXCH;  i++) {
 	    if (i == CINDEX (kwtbl[j].keyw[0])) {
 		kwindex[i] = j;
 		j = min (LEN_KWTBL-1, j + kwtbl[j].nelem + 1);
@@ -253,7 +283,8 @@ hashtbl()
 /* FINDKW -- Lookup an indentifier in the keyword table.  Return the opcode
  * of the keyword, or ERR if no match.
  */
-findkw()
+int
+findkw (void)
 {
 	register char ch, *p, *q;
 	int	i, ilimit;
@@ -293,7 +324,8 @@ findkw()
  * keywords are mapped into special x$.. identifiers for further processing
  * by the second pass.
  */
-mapident()
+void
+mapident (void)
 {
 	int     i, findkw();
 	char	*str_fetch();
@@ -376,15 +408,17 @@ int	st_nstr = 0;
  * strings.  The name must be upper case or the table will not be searched.
  *
  * N.B.: we are called by the lexical analyser with 'define name "' in
- * yytext.  The next input() will return the first char of the string.
+ * yytext.  The next yy_input() will return the first char of the string.
  */
-str_enter()
+void
+str_enter (void)
 {
 	register char	*ip, *op, ch;
 	register struct st_def *s;
 	register int	n;
 	char	name[SZ_FNAME+1];
 
+
 	/* Skip to the first char of the name string.
 	 */
 	ip = yytext;
@@ -421,7 +455,7 @@ str_enter()
 		error (XPP_COMPERR, "Too many defined strings");
 
 	    /* Put defined NAME in string buffer.  */
-	    for (s->st_name = st_next, ip=name;  *st_next++ = *ip++;  )
+	    for (s->st_name = st_next, (ip=name);  (*st_next++ = *ip++);  )
 		;
 	}
 
@@ -442,8 +476,7 @@ str_enter()
  * parameter and return a pointer to the string if found, NULL otherwise.
  */
 char *
-str_fetch (strname)
-register char *strname;
+str_fetch (register char *strname)
 {
 	register struct st_def *s = st_list;
 	register int n = st_nstr;
@@ -460,12 +493,132 @@ register char *strname;
 }
 
 
+/*  MACRO_REDEF --  Redefine the macro to automatically add a P2<T> macro
+ *  to struct definitions.
+ */
+void
+macro_redef (void)
+{
+	register int	nb=0;
+	register char	*ip, *op, ch;
+	char	name[SZ_FNAME];
+	char	value[SZ_LINE];
+
+
+	outstr ("define\t");
+	memset (name, 0, SZ_FNAME);
+	memset (value, 0, SZ_LINE);
+
+	/* Skip to the first char of the name string.
+	 */
+	ip = yytext;
+	while (isspace (*ip))
+	    ip++;
+	while (!isspace (*ip))
+	    ip++;
+	while (isspace (*ip))
+	    ip++;
+
+	/* Extract macro name. */
+	for (op=name;  (isalnum(*ip) || *ip == '_');  )
+	    *op++ = *ip++;
+	*op = EOS;
+	outstr (name);
+	outstr ("\t");
+
+
+	/*  Modify value.
+	 */
+	op = value;
+        while ( (ch = yy_input()) != EOF ) {
+	    if (ch == '\n') {
+		break;
+	    } else if (ch == '#') {		/* eat a comment	*/
+		while ((ch = yy_input()) != '\n')
+		    ;
+		break;
+
+
+	    } else {
+		if (ch == '[') {
+		    nb++; 
+		    if (nb > 1) *op++ = '(';
+		} else if (ch == ']') {
+		    nb--; 
+		    if (nb <= 0)
+		        break;
+		    else
+		        *op++ = ')';
+		} else if (nb >= 1)
+		    *op++ = ch;
+	    }
+	}
+
+	outstr ("Memr(");
+	if (strcmp (value, "$1") == 0) {
+#ifdef AUTO_P2R
+	    char *emsg[SZ_LINE];
+	    int strict = 0;
+#endif
+
+	    /*  A macro such as "Memr[$1]" which is typically used as a 
+	     *  shorthand for an array allocated as TY_REAL and not a part
+	     *  of a struct, however it might also be the first element of
+	     *  a struct.  In this case, print a warning so it can be checked
+	     *  manually and just pass it through.
+	     */
+#ifdef AUTO_P2R
+	    memset (emsg, 0, SZ_LINE);
+	    sprintf (emsg, 
+		"Error in %s: line %d: ambiguous Memr for '%s' needs P2R/P2P", 
+		fname[istkptr], linenum[istkptr], name);
+	    if (strict)
+	        error (XPP_COMPERR, emsg);
+	    else
+		fprintf (stderr, "%s\n", emsg);
+#endif
+	    outstr (value);
+
+	} else if (strncmp ("Mem", value, 3) == 0 || isupper (value[0])) {
+	    /*  In this case we assume a complex macro using some other
+	     *  Mem element or an upper-case macro.  These are again used
+	     *  typically as a shorthand and use pointers directly, so pass
+	     *  it through unchanged.
+	     */
+	    outstr (value);
+
+	} else {
+	    /*  Assume it's part of a struct, e.g. "Memr[$1+N]".  
+	     *
+	     *  FIXME --  We should really be more careful to check the syntax.
+	    fprintf (stderr, "INFO %s line %d: ", 
+		fname[istkptr], linenum[istkptr]);
+	    fprintf (stderr, "adding P2R macro for '%s'\n", name);
+	     */
+#ifdef AUTO_P2R
+	    if (value[0] == '$') {
+	        outstr ("P2R(");
+	        outstr (value);
+	        outstr (")");
+	    } else
+	        outstr (value);
+#else
+	    outstr (value);
+#endif
+	}
+	outstr (")\n");
+
+	linenum[istkptr]++;
+}
+
+
 /* SETLINE -- Set the file line number.  Used by the first pass to set
  * line number after processing an include file and in various other
  * places.  Necessary to get correct line numbers in error messages from
  * the second pass.
  */
-setline()
+void
+setline (void)
 {
 	char	msg[20];
 
@@ -482,8 +635,8 @@ setline()
  *
  * NOTE -- the redirection logic shown below is duplicated in OUTSTR.
  */
-output (ch)
-char	ch;
+void
+output (char ch)
 {
 	if (context & (BODY|DATASTMT)) {
 	    /* In body of procedure or in a data statement (which is output
@@ -511,164 +664,6 @@ char	ch;
 }
 
 
-/* DO_INCLUDE -- Process an include statement, i.e., eat up the include
- * statement, push the current input file on a stack, and open the new file.
- * System include files are referenced as "<file>", other files as "file".
- */
-do_include()
-{
-	char    *p, delim, *rindex();
-	int	root_len;
-	int	strcmp();
-
-	/* Push current input file status on the input file stack istk.
-	 */
-	istk[istkptr] = yyin;
-	if (++istkptr >= MAX_INCLUDE) {
-	    --istkptr;
-	    error (XPP_COMPERR, "Maximum include nesting exceeded");
-	    return;
-	}
-
-	/* If filespec "<file>", call os_sysfile to get the pathname of the
-	 * system include file.
-	 */
-	if (yytext[yyleng-1] == '<') {
-	    char   hfile[SZ_FNAME+1], *op;
-
-	    for (op=hfile;  (*op = input()) != EOF;  op++)
-		if (*op == '\n') {
-		    --istkptr;
-		    error (XPP_SYNTAX, "missing > delim in include statement");
-		    return;
-		} else if (*op == '>')
-		    break;
-
-	    *op = EOS;
-
-	    if (os_sysfile (hfile, fname[istkptr], SZ_PATHNAME) == ERR) {
-		--istkptr;
-		error (XPP_COMPERR, "cannot find include file");
-		return;
-	    }
-
-	} else {
-	    /* Prepend pathname leading to the file in which the current
-	     * include statement was found.  Compiler may not have been run
-	     * from the directory containing the source and include file.
-	     */
-	    if ((p = rindex (fname[istkptr-1], '/')) == NULL)
-		root_len = 0;
-	    else
-		root_len = p - fname[istkptr-1] + 1;
-
-	    strncpy (fname[istkptr], fname[istkptr-1], root_len);
-	    fname[istkptr][root_len] = EOS;
-
-	    delim = '"';
-
-	    /* Advance to end of whatever is in the file name string.
-	     */
-	    for (p=fname[istkptr];  *p != EOS;  p++)
-		;
-	    /* Concatenate name of referenced file.
-	     */
-	    while ((*p = input()) != delim) {
-		if (*p == '\n' || *p == EOF) {
-		    --istkptr;
-		    error (XPP_SYNTAX, "bad include file name");
-		    return;
-		}
-		p++;
-	    }
-	    *p = EOS;
-	}
-
-	/* If the foreign defs option is in effect, the machine dependent defs
-	 * for a foreign machine are given by a substitute "iraf.h" file named
-	 * on the command line.  This foreign machine header file includes
-	 * not only the iraf.h for the foreign machine, but the equivalent of
-	 * all the files named in the array of strings "machdefs".  Ignore any
-	 * attempts to include any of these files since they have already been
-	 * included in the foreign definitions header file.
-	 */
-	if (foreigndefs) {
-	    char	sysfile[SZ_PATHNAME];
-	    char	**files;
-
-	    for (files=machdefs;  *files != NULL;  files++) {
-		strcpy (sysfile, HOSTLIB);
-		strcat (sysfile, *files);
-		if (strcmp (sysfile, fname[istkptr]) == 0) {
-		    --istkptr;
-		    return;
-		}
-	    }
-	}
-
-	if ((yyin = fopen (vfn2osfn(fname[istkptr],0), "r")) == NULL) {
-	    yyin = istk[--istkptr];
-	    error (XPP_SYNTAX, "Cannot open include file");
-	    return;
-	}
-
-	/* Keep track of the line number within the include file.  */
-	linenum[istkptr] = 1;
-
-	/* Put the newline back so that LEX "^..." matches will work on
-	 * first line of include file.
-	 */
-	unput ('\n');
-}
-
-
-/* YYWRAP -- Called by LEX when end of file is reached.  If input stack is
- * not empty, close off include file and continue on in old file.  Return 
- * nonzero when the stack is empty, i.e., when we reach the end of the
- * main file.
- */
-yywrap()
-{
-	/* The last line of a file is not necessarily newline terminated.
-	 * Output a newline just in case.
-	 */
-	fprintf (yyout, "\n");
-
-	if (istkptr <= 0) {
-	    /* ALL DONE with main file.
-	     */
-	    return (1);
-
-	} else {
-	    /* End of include file.  Pop old input file and set line number
-	     * for error messages.
-	     */
-	    fclose (yyin);
-	    yyin = istk[--istkptr];
-	    if (istkptr == 0)
-		setline();
-	    return (0);
-	}
-}
-
-
-/* YY_INPUT -- Get a character from the input stream.
- */
-yy_input()
-{
-	return (input());
-}
-
-
-/* YY_UNPUT -- Put a character back into the input stream.
- */
-yy_unput(ch)
-char	ch;
-{
-	unput(ch);
-}
-
-
 /* Datatype keywords for declarations.  The special x$.. keywords are 
  * for communication with the second pass.  Note that this table is machine
  * dependent, since it maps char into type short.
@@ -711,15 +706,15 @@ char	*intrinsic_function[] = {
  * is properly resolved by processing macros BEFORE code generation.
  * In the current implementation, macros are handled by the second pass (RPP).
  */
-do_type (type)
-int	type;
+void
+do_type (int type)
 {
 	char    ch;
 
 	if (context & (BODY|DEFSTMT)) {
 	    switch (type) {
 	    case XTY_BOOL:
-		for (ch=input();  ch == ' ' || ch == '\t';  ch=input())
+		for (ch=yy_input();  ch == ' ' || ch == '\t';  ch=yy_input())
 		    ;
 		if (ch != '(')
 		    error (XPP_SYNTAX, "Illegal boolean expr");
@@ -744,7 +739,7 @@ int	type;
 	} else {
 	    /* UNREACHABLE when in declarations section of a procedure.
 	     */
-	    fprintf (yyout, type_decl[type]);
+	    fprintf (yyout, "%s", type_decl[type]);
 	}
 }
 
@@ -754,14 +749,15 @@ int	type;
  * "char name[".  If we reach the closing ']', convert it into a right paren
  * for the second pass.
  */
-do_char()
+void
+do_char (void)
 {
 	char	ch;
 
-	for (ch=input();  ch != ',' && ch != ']';  ch=input())
+	for (ch=yy_input();  ch != ',' && ch != ']';  ch=yy_input())
 	    if (ch == '\n' || ch == EOS) {
 		error (XPP_SYNTAX, "Missing comma or ']' in char declaration");
-		unput ('\n');
+		yy_unput ('\n');
 		return;
 	    } else
 		output (ch);
@@ -776,8 +772,13 @@ do_char()
 
 /* SKIP_HELPBLOCK -- Skip over a help block (documentation section).
  */
-skip_helpblock()
+void
+skip_helpblock (void)
 {
+	char   ch;
+
+
+	/*  fgets() no longer works with FLEX 
 	while (fgets (yytext, SZ_LINE, yyin) != NULL) {
 	    if (istkptr == 0)
 		linenum[istkptr]++;
@@ -789,62 +790,32 @@ skip_helpblock()
 			break;
 	    }
 	}
-}
-
-
-/* PROCESS_TASK_STATEMENT -- Parse the TASK statement.  The task statement
- * is replaced by the "sys_runtask" procedure (sysruk), which is called by
- * the IRAF main to run a task, or to print the dictionary (cmd "?").
- * The source for the basic sys_runtask procedure is in "lib$sysruk.x".
- * We process the task statement into some internal tables, then open the
- * sysruk.x file as an include file.  Special macros therein are
- * replaced by the taskname dictionary as processing continues.
- */
-process_task_statement()
-{
-	char	ch;
-
-	if (ntasks > 0) {		/* only one task statement permitted */
-	    error (XPP_SYNTAX, "Only one TASK statement permitted per file");
-	    return;
-	}
-
-	/* Process the task statement into the TASK_LIST structure.
-	 */
-	if (parse_task_statement() == ERR) {
-	    error (XPP_SYNTAX, "Syntax error in TASK statement");
-	    while ((ch = input()) != EOF && ch != '\n')
-		;
-	    unput ('\n');
-	    return;
-	}
-
-	/* Open RUNTASK ("lib$sysruk.x") as an include file.
-	 */
-	istk[istkptr] = yyin;
-	if (++istkptr >= MAX_INCLUDE) {
-	    istkptr--;
-	    error (XPP_COMPERR, "Maximum include nesting exceeded");
-	    return;
-	}
-
-	strcpy (fname[istkptr], IRAFLIB);
-	strcat (fname[istkptr], RUNTASK);
-	if ((yyin = fopen (vfn2osfn (fname[istkptr],0), "r")) == NULL) {
-	    yyin = istk[--istkptr];
-	    error (XPP_SYNTAX, "Cannot read lib$sysruk.x");
-	    return;
-	}
-
-	linenum[istkptr] = 1;
-
-	/* Put the newline back so that LEX "^..." matches will work on
-	 * first line of the include file.
-	 */
-	unput ('\n');
-}
+	*/
 
+	while ( (ch = yy_input()) != EOF ) {
+	    if (ch == '.') {		/* check for ".endhelp"		*/
+		ch = yy_input();
+		if (ch == 'e' || ch == 'E') {
+		    for (ch = yy_input() ; ch != '\n' && ch != EOS;  ch=yy_input())
+	    	        ;
+		    break;
+		} else
+		    for (ch = yy_input() ; ch != '\n' && ch != EOS;  ch=yy_input())
+	    	        ;
 	
+	    } else if (ch == '\n') {	/* skip line			*/
+		;
+	    } else {
+		for (ch=yy_input();  ch != '\n' && ch != EOS;  ch=yy_input())
+	    	    ;
+	    }
+	    if (istkptr == 0)
+	        linenum[istkptr]++;
+        }
+	linenum[istkptr]++;
+}
+
+
 /* PARSE_TASK_STATEMENT -- Parse the task statement, building up a list
  *   of task_name/procedure_name structures in the "task_list" array.
  *
@@ -861,7 +832,8 @@ process_task_statement()
  * N.B.: Upon entry, the input is left positioned to just past the "task"
  *   keyword.
  */
-parse_task_statement()
+int
+parse_task_statement (void)
 {
 	register struct task *tp;
 	register char ch, *ip;
@@ -905,9 +877,8 @@ parse_task_statement()
 	    ch = nextch();
 	    if (ch == ',') {
 		if ((ch = nextch()) != '\n')
-		    unput (ch);
+		    yy_unput (ch);
 	    } else if (ch == '\n') {
-		linenum[istkptr]++;
 		ntasks++;			/* end of task statement */	
 		break;
 	    } else
@@ -938,10 +909,8 @@ err:	    error (XPP_COMPERR, "too many tasks in task statement");
 /* GET_TASK -- Process a single task declaration of the form "taskname" or
  * "taskname = procname".
  */
-get_task (task_name, proc_name, maxch)
-char	*task_name;
-char	*proc_name;
-int	maxch;
+int
+get_task (char *task_name, char *proc_name, int maxch)
 {
 	register char ch;
 
@@ -957,7 +926,7 @@ int	maxch;
 	    if (get_name (proc_name, maxch) == ERR)
 		return (ERR);
 	} else {
-	    unput (ch);
+	    yy_unput (ch);
 	    strncpy (proc_name, task_name, maxch);
 	}
 
@@ -969,17 +938,16 @@ int	maxch;
  * ERR is returned if the output string overflows, or if the token is not
  * a legal identifier.
  */
-get_name (outstr, maxch)
-char	*outstr;
-int	maxch;
+int
+get_name (char *outstr, int maxch)
 {
 	register char ch, *op;
 	register int nchars;
 
-	unput ((ch = nextch()));	/* skip leading whitespace	*/
+	yy_unput ((ch = nextch()));	/* skip leading whitespace	*/
 
 	for (nchars=0, op=outstr;  nchars < maxch;  nchars++) {
-	    ch = input();
+	    ch = yy_input();
 	    if (isalpha(ch)) {
 		if (isupper(ch))
 		    *op++ = tolower(ch);
@@ -989,7 +957,7 @@ int	maxch;
 		*op++ = ch;
 	    } else {
 		*op++ = EOS;
-		unput (ch);
+		yy_unput (ch);
 		return (nchars > 0 ? XOK : ERR);
 	    }
 	}
@@ -1001,13 +969,14 @@ int	maxch;
 /* NEXTCH -- Get next nonwhite character from the input stream.  Ignore
  * comments.  Newline is not considered whitespace.
  */
-nextch()
+int
+nextch (void)
 {
 	register char ch;
 
-	while ((ch = input()) != EOF) {
+	while ((ch = yy_input()) != EOF) {
 	    if (ch == '#') {			/* discard comment */
-		while ((ch = input()) != '\n')
+		while ((ch = yy_input()) != '\n')
 		    ;
 		return (ch);
 	    } else if (ch != ' ' && ch != '\t')
@@ -1026,7 +995,8 @@ nextch()
  */
 #define	NDP_PERLINE		8	/* num DP data elements per line */
 
-put_dictionary()
+void
+put_dictionary (void)
 {
 	register struct task *tp;
 	char	buf[SZ_LINE];
@@ -1035,9 +1005,9 @@ put_dictionary()
 	/* Discard anything found on line after the TN$DECL, which is only
 	 * recognized as the first token on the line.
 	 */
-	while (input() != '\n')
+	while (yy_input() != '\n')
 	    ;
-	unput ('\n');
+	yy_unput ('\n');
 
 	/* Output the data statements required to initialize the DP array.
 	 * These statements are spooled into the output buffer and not output
@@ -1089,14 +1059,15 @@ put_dictionary()
  * for a task and call the associated procedure.  We are called when the
  * keyword TN$INTERP is encountered in the input stream.
  */
-put_interpreter()
+void
+put_interpreter (void)
 {
 	char	lbuf[SZ_LINE];
 	int	i;
 
-	while (input() != '\n')		/* discard rest of line */
+	while (yy_input() != '\n')		/* discard rest of line */
 	    ;
-	unput ('\n');
+	yy_unput ('\n');
 
 	for (i=0;  i < ntasks;  i++) {
 	    sprintf (lbuf, "\tif (streq (task, dict(dp(%d)))) {\n", i+1);
@@ -1115,11 +1086,12 @@ put_interpreter()
  * either go direct to the output file, or will be buffered in the output
  * buffer.
  */
-outstr (string)
-char	*string;
+void
+outstr (char *string)
 {
 	register char *ip;
 
+
 	if (context & (BODY|DATASTMT)) {
 	    /* In body of procedure or in a data statement (which is output
 	     * just preceding the body).
@@ -1152,7 +1124,8 @@ char	*string;
  * i.e., when we begin processing the executable part of a procedure
  * declaration.
  */
-begin_code()
+void
+begin_code (void)
 {
 	char	text[1024];
 
@@ -1189,7 +1162,8 @@ begin_code()
  * output.  Finally, we output the spooled procedure body, followed by and END
  * statement for the benefit of the second pass.
  */
-end_code()
+void
+end_code (void)
 {
 	int	i;
 
@@ -1232,7 +1206,8 @@ end_code()
 	 * data statement declaration.
 	 */
 	*dp++ = EOS;
-	fputs (dbuf, yyout);
+	fputs (dbuf, yyout); fflush (yyout);
+{ int i; for (i=0; i < SZ_DBUF; ) dbuf[i++] = '\0'; }
 	dp = dbuf;
 
 	/* Output the SAVE statement, which must come after all declarations
@@ -1251,8 +1226,9 @@ end_code()
 	 */
 	init_strings();
 	*op++ = EOS;
-	fputs (obuf, yyout);
-	fputs ("end\n", yyout);
+	fputs (obuf, yyout); fflush (yyout);
+{ int i; for (i=0; i < SZ_OBUF; ) obuf[i++] = '\0'; }
+	fputs ("end\n", yyout); fflush (yyout);
 
 	op = obuf;
 	*op = EOS;
@@ -1274,7 +1250,8 @@ end_code()
  * smallest integer datatype provided by the host Fortran compiler, usually
  * INTEGER*2 (XTY_CHAR).
  */
-init_strings()
+void
+init_strings (void)
 {
 	register int str;
 
@@ -1305,8 +1282,8 @@ init_strings()
  * on some compilers (crazy but true).  Determine if we will be generating any
  * implied dos and declare the variable if so.
  */
-write_string_data_statement (s)
-struct	string *s;
+void
+write_string_data_statement (struct string *s)
 {
 	register int i, len;
 	register char *ip;
@@ -1350,9 +1327,11 @@ struct	string *s;
  * save name of string array in sbuf.  If inline string, manufacture the
  * name of the string array.
  */
-do_string (delim, strtype)
-char	delim;				/* char which delimits string	*/
-int	strtype;			/* string type			*/
+void
+do_string (
+  char	delim,				/* char which delimits string	*/
+  int	strtype 			/* string type			*/
+)
 {
 	register char ch, *ip;
 	register struct string *s;
@@ -1395,15 +1374,15 @@ int	strtype;			/* string type			*/
 	    *sp++ = ch;
 
 	    /* Get rest of string name identifier. */
-	    while ((ch = input()) != EOF) {
+	    while ((ch = yy_input()) != EOF) {
 		if (isalnum(ch) || ch == '_') {
 		    *sp++ = ch;
 	    	    sbuf_check();
 		} else if (ch == '\n') {
 sterr:		    error (XPP_SYNTAX, "String declaration syntax");
-		    while (input() != '\n')
+		    while (yy_input() != '\n')
 			;
-		    unput ('\n');
+		    yy_unput ('\n');
 		    return;
 		} else {
 		    *sp++ = EOS;
@@ -1428,12 +1407,12 @@ sterr:		    error (XPP_SYNTAX, "String declaration syntax");
 		 */
 		op = yytext;
 		*op++ = delim;
-		while ((ch = input()) != EOF)
+		while ((ch = yy_input()) != EOF)
 		    if (isalnum(ch) || ch == '_')
 			*op++ = ch;
 		    else
 			break;
-		unput (ch);
+		yy_unput (ch);
 		*op = EOS;
 
 		/* Fetch body of string into yytext.
@@ -1497,14 +1476,15 @@ sterr:		    error (XPP_SYNTAX, "String declaration syntax");
  * as in the statement 'call_f77_sub (arg, *"any string", arg)'.  Escape
  * sequences are not recognized.
  */
-do_hollerith()
+void
+do_hollerith (void)
 {
 	register char *op;
 	char	strbuf[SZ_LINE], outbuf[SZ_LINE];
 	int	len;
 
 	/* Read the string into strbuf. */
-	for (op=strbuf, len=0;  (*op = input()) != '"';  op++, len++)
+	for (op=strbuf, len=0;  (*op = yy_input()) != '"';  op++, len++)
 	    if (*op == '\n' || *op == EOF)
 		break;
 	if (*op == '\n')
@@ -1512,12 +1492,7 @@ do_hollerith()
 	else
 	    *op = EOS;				/* delete delimiter */
 
-#ifdef F77
 	sprintf (outbuf, "\'%s\'", strbuf);
-#else
-	sprintf (outbuf, "%dH%s", i, strbuf);
-#endif
-
 	outstr (outbuf);
 }
 
@@ -1525,7 +1500,8 @@ do_hollerith()
 /* SBUF_CHECK -- Check to see that the string buffer has not overflowed.
  * It is a fatal error if it does.
  */
-sbuf_check()
+void
+sbuf_check (void)
 {
 	if (sp >= &sbuf[SZ_SBUF]) {
 	    error (XPP_COMPERR, "String buffer overflow");
@@ -1537,7 +1513,7 @@ sbuf_check()
 /* STR_UNIQID -- Generate a unit identifier name for an inline string.
  */
 char *
-str_uniqid()
+str_uniqid (void)
 {
 	static  char id[] = "ST0000";
 
@@ -1555,42 +1531,42 @@ str_uniqid()
  * Quotes may be included in the string by escaping them, or by means of
  * the double quote convention.
  */
-traverse (delim)
-char	delim;
+void
+traverse (char delim)
 {
 	register char *op, *cp, ch;
 	char	*index();
 
-	for (op=yytext;  (*op = input()) != EOF;  op++) {
+
+	for (op=yytext;  (*op = yy_input()) != EOF;  op++) {
 	    if (*op == delim) {
-		if ((*op = input()) == EOF)
+		if ((*op = yy_input()) == EOF)
 		    break;
 		if (*op == delim)
 		    continue;		/* double quote convention; keep one */
 		else {
-		    unput (*op);
+		    yy_unput (*op);
 		    break;			/* normal exit		*/
 		}
 
 	    } else if (*op == '\n') {		/* error recovery exit	*/
-		unput ('\n');
+		yy_unput ('\n');
 		xpp_warn ("Newline while processing string");
 		break;
 
 	    } else if (*op == '\\') {
-		if ((*op = input()) == EOF) {
+		if ((*op = yy_input()) == EOF) {
 		    break;
 		} else if (*op == '\n') {
 		    --op;			/* explicit continuation */
-		    linenum[istkptr]++;
 		    continue;
 		} else if ((cp = index (esc_ch, *op)) != NULL) {
 		    *op = esc_val[cp-esc_ch];
 		} else if (isdigit (*op)) {	/* '\0DD' octal constant */
 		    *op -= '0';
-		    while (isdigit (ch = input()))
+		    while (isdigit (ch = yy_input()))
 			*op = (*op * 8) + (ch - '0');
-		    unput (ch);
+		    yy_unput (ch);
 		} else {
 		    ch = *op;			/* unknown escape sequence, */
 		    *op++ = '\\';		/* leave it alone.	    */
@@ -1608,9 +1584,8 @@ char	delim;
  * Do not abort compiler, however, because it is better to keep going and
  * find all the errors in a single compilation.
  */
-error (errcode, errmsg)
-int	errcode;
-char	*errmsg;
+void
+error (int errcode, char *errmsg)
 {
 	fprintf (stderr, "Error on line %d of %s: %s\n", linenum[istkptr],
 	    fname[istkptr], errmsg);
@@ -1619,12 +1594,12 @@ char	*errmsg;
 }
 
 
-/* XPP_WARN -- Output a warning message.  Do not set exit flag since this is
- * only a warning message; linking should occur if there are not any more
- * serious errors.
+/* WARN -- Output a warning message.  Do not set exit flag since this is only
+ * a warning message; linking should occur if there are not any more serious
+ * errors.
  */
-xpp_warn (warnmsg)
-char	*warnmsg;
+void
+xpp_warn (char *warnmsg)
 {
 	fprintf (stderr, "Warning on line %d of %s: %s\n", linenum[istkptr],
 	    fname[istkptr], warnmsg);
@@ -1637,9 +1612,7 @@ char	*warnmsg;
  * indicated base.
  */
 long
-accum (base, strp)
-int	base;
-char	**strp;
+accum (int base, char **strp)
 {
 	register char *ip;
 	long    sum;
@@ -1682,8 +1655,8 @@ char	**strp;
  * The regular escape sequences are recognized; numeric values are assumed
  * to be octal.
  */
-charcon (string)
-char	*string;
+int
+charcon (char *string)
 {
 	register char *ip, ch;
 	char	*cc, *index();
@@ -1714,9 +1687,8 @@ char	*string;
  * octal, or sexagesimal number, or a character constant.  The numeric string
  * is converted in the indicated base and replaced by its decimal value.
  */
-int_constant (string, base)
-char	*string;
-int	base;
+void
+int_constant (char *string, int base)
 {
 	char    decimal_constant[SZ_NUMBUF], *p;
 	long    accum(), value;
@@ -1740,12 +1712,12 @@ int	base;
 	    break;
 
 	case CHARCON:
-	    while ((p[i] = input()) != EOF) {
+	    while ((p[i] = yy_input()) != EOF) {
 		if (p[i] == '\n') {
 	    	    error (XPP_SYNTAX, "Undelimited character constant");
 	    	    return;
 		} else if (p[i] == '\\') {
-	    	    p[++i] = input();
+	    	    p[++i] = yy_input();
 	    	    i++;
 	    	    continue;
 		} else if (p[i] == '\'')
@@ -1773,9 +1745,8 @@ int	base;
  * the preceeding field.  Thus "12:30" is equivalent to "12.5".  Some care
  * is taken to preserve the precision of the number.
  */
-char *
-hms (number)
-char	*number;
+void
+hms (char *number)
 {
 	char	cvalue[SZ_NUMBUF], *ip;
 	int	bvalue, ndigits;
@@ -1808,9 +1779,9 @@ char	*number;
 
 	/* Format the output number. */
 	if (ndigits > MIN_REALPREC)
-	    sprintf (cvalue, "%d.%dD0", bvalue, value);
+	    sprintf (cvalue, "%d.%ldD0", bvalue, value);
 	else
-	    sprintf (cvalue, "%d.%d", bvalue, value);
+	    sprintf (cvalue, "%d.%ld", bvalue, value);
 	cvalue[ndigits+1] = '\0';
 
 	/* Print the translated number. */
