@@ -3,6 +3,12 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <stdlib.h>
+#include <unistd.h>
+
+#include "sgiUtil.h"
+
 
 /*
  *  SGI2GIF.C -- Read an IRAF SGI bitmap file on standard input and convert
@@ -76,18 +82,17 @@ static int blue[]  = { DEF_BG, DEF_FG } ;
 static char *infile[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 static char *s_root = "sgigif_";
 
-static int	GIFNextPixel(), isSwappedMachine();
+static int	GIFNextPixel();
 static void 	BumpPixel(), GIFEncode(), Putword(), compress();
 static void 	output(), cl_block(), cl_hash(), char_init();
-static void 	char_out(), flush_char(), unpack1to8(), bswap4();
+static void 	char_out(), flush_char(), unpack1to8();
 
 
 
 /* MAIN -- Main entry point for the task.
  */
-main (argc, argv)
-int	argc;
-char	**argv;
+int
+main (int argc, char *argv[])
 {
 	FILE	*fdi, *fdo;
 	char	fname[SZ_FNAME];
@@ -187,7 +192,7 @@ char	**argv;
 		 * it's in the correct order for unpacking to be interpreted
 		 * as an LSB-ordered image.
 	         */
-	        if ( ! isSwappedMachine())
+	        if ( ! isSwapped ())
 		    bswap4 (buffer, buffer, len_buf);
 
 	        unpack1to8 ((ip+=px), buffer, px);
@@ -197,16 +202,19 @@ char	**argv;
 	    GIFEncode (fdo, px, py, (interlace=0), (background=0), (bpp=1),
 		red, green, blue);
 
+	    fflush (fdi);
+	    fflush (fdo);
 	    if (fdi != stdin)
 	        fclose (fdi);
 	    if (fdo != stdout)
-	        fclose (fdi);
-	    fflush (fdi);
+	        fclose (fdo);
 	}
 
 	/* Clean up. */
 	free (buffer);
 	free (pixels);
+
+	return (0);
 }
 
 
@@ -214,9 +222,7 @@ char	**argv;
  */
 
 static void
-unpack1to8 (dest, src, len)
-byte 	*dest, *src;
-int 	len;
+unpack1to8 (byte *dest, byte *src, int len)
 {
         register int i, b;
         byte 	c = 0;
@@ -231,63 +237,6 @@ int 	len;
 }
 
 
-/* IS_SWAPPED_MACHINE -- See if this is a byte-swapped (LSB) machine.
- */
-
-static int
-isSwappedMachine ()
-{
-        union {
-            char ch[4];
-            int  i;
-        } u;
-
-        u.i = 1;
-        return ((int) u.ch[0]);
-}
-
-
-/* BSWAP4 - Move bytes from array "a" to array "b", swapping the four bytes
- * in each successive 4 byte group, i.e., 12345678 becomes 43218765.
- * The input and output arrays may be the same but may not partially overlap.
- */
-static void
-bswap4 (a, b, nbytes)
-byte   *a;                     /* input array                  */
-byte   *b;                     /* output array                 */
-int    nbytes;                 /* number of bytes to swap      */
-{
-        register byte   *ip, *op, *tp;
-        register int    n;
-        static   byte temp[4];
-
-        tp = temp;
-        ip = (byte *)a;
-        op = (byte *)b;
-
-        /* Swap successive four byte groups.
-         */
-        for (n = nbytes >> 2;  --n >= 0;  ) {
-            *tp++ = *ip++;
-            *tp++ = *ip++;
-            *tp++ = *ip++;
-            *tp++ = *ip++;
-            *op++ = *--tp;
-            *op++ = *--tp;
-            *op++ = *--tp;
-            *op++ = *--tp;
-        }
-
-        /* If there are any odd bytes left, move them to the output array.
-         * Do not bother to swap as it is unclear how to swap a partial
-         * group, and really incorrect if the data is not modulus 4.
-         */
-        for (n = nbytes & 03;  --n >= 0;  )
-            *op++ = *ip++;
-}
-
-
-
 /* GIF Writing Procedures.
  *
  * Based on GIFENCOD by David Rowley <mgardi@watdscu.waterloo.edu>.  A
