@@ -2,29 +2,29 @@
  */
 
 #include <stdio.h>
+#include <unistd.h>
 
 #define import_spp
 #define	import_kernel
 #define	import_knames
 #include <iraf.h>
 
-extern	char oscwd[];			/* See ZFCHDR		*/
+extern	char oscwd[];
+
 
 /* ZFGCWD -- Get working (current) UNIX directory.  The current working
  * directory, once set, is saved in oscwd.
  */
-ZFGCWD (outstr, maxch, status)
-PKCHAR	*outstr;
-XINT	*maxch, *status;
+int
+ZFGCWD (
+  PKCHAR  *outstr,
+  XINT	  *maxch, 
+  XINT    *status
+)
 {
 	register char	*ip, *op;
 	register int	n;
 	char	dirname[1025];
-#ifdef POSIX
-	char	*getcwd();
-#else
-	char	*getwd();
-#endif
 
 	/* If cwd is already known, just return the name.  Reconstructing
 	 * the pathname of the cwd is expensive on some systems.
@@ -32,14 +32,10 @@ XINT	*maxch, *status;
 	if (oscwd[0] != EOS)
 	    ip = oscwd;
 	else {
-#ifdef POSIX
 	    ip = getcwd (dirname, 1024);
-#else
-	    ip = getwd (dirname);
-#endif
 	    if (ip == NULL) {
 		*status = XERR;
-		return;
+		return (XERR);
 	    } else
 		strcpy (oscwd, dirname);
 	}
@@ -56,4 +52,6 @@ XINT	*maxch, *status;
 	}
 
 	*status = op - (char *)outstr;
+
+	return (*status);
 }
