@@ -1,6 +1,9 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include <stdio.h>
 #define	import_kernel
 #define	import_knames
@@ -9,13 +12,18 @@
 
 /* ZFMKDR -- Create a new directory.
  */
-ZFMKDR (newdir, status)
-PKCHAR	*newdir;
-XINT	*status;
+int
+ZFMKDR (
+  PKCHAR  *newdir,
+  XINT	  *status
+)
 {
 	char	osdir[SZ_PATHNAME];
 	register char *ip, *op;
 
+	extern  int _u_fmode();
+
+
 	/* Change pathnames like "a/b/c/" to "a/b/c".  Probably not necessary,
 	 * but...
 	 */
@@ -26,6 +34,11 @@ XINT	*status;
 
 	if (mkdir (osdir, _u_fmode(0777)) == ERR)
 	    *status = XERR;
-	else
+	else {
+	    if (strncmp (osdir, "/tmp", 4) == 0)
+	        chmod (osdir, _u_fmode(0777));
 	    *status = XOK;
+	}
+
+	return (*status);
 }
