@@ -2,6 +2,7 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 
 #define	import_spp
 #define	import_knames
@@ -10,23 +11,28 @@
 extern	char os_process_name[];
 extern	PKCHAR osfn_bkgfile[];
 extern	int save_prtype;
-extern	ipc_isatty;
-extern	ipc_in, ipc_out;
+extern	int ipc_isatty;
+extern	int ipc_in, ipc_out;
 
 /* ZZSETK -- Internal kernel routine, used by the zmain to set the values
  * of certain internal kernel parameters.
  */
-ZZSETK (ospn, osbfn, prtype, isatty, in, out)
-char	*ospn;
-char	*osbfn;
-int	prtype;
-int	isatty;
-int	in, out;
+int
+ZZSETK (
+  char	*ospn,
+  char	*osbfn,
+  int	prtype,
+  int	isatty,
+  int	in, 
+  int   out
+)
 {
 	strcpy (os_process_name, ospn);
-	strcpy (osfn_bkgfile, osbfn);
+	strcpy ((char *)osfn_bkgfile, osbfn);
 	save_prtype = prtype;
 	ipc_isatty = isatty;
 	ipc_in = in;
 	ipc_out = out;
+
+	return (XOK);
 }
